# This file was auto-generated by Fern from our API Definition.

import typing

from ...core.client_wrapper import AsyncClientWrapper, SyncClientWrapper
from ...core.request_options import RequestOptions
from ...types.project_group_request import ProjectGroupRequest
from ...types.saml_settings import SamlSettings
from ...types.saml_settings_update import SamlSettingsUpdate
from .raw_client import AsyncRawSamlClient, RawSamlClient

# this is used as the default value for optional parameters
OMIT = typing.cast(typing.Any, ...)


class SamlClient:
    def __init__(self, *, client_wrapper: SyncClientWrapper):
        self._raw_client = RawSamlClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> RawSamlClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        RawSamlClient
        """
        return self._raw_client

    def get(self, *, request_options: typing.Optional[RequestOptions] = None) -> SamlSettings:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve SAML2 settings for the currently active organization.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SamlSettings


        Examples
        --------
        from label_studio_sdk import LabelStudio

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.sso.saml.get()
        """
        _response = self._raw_client.get(request_options=request_options)
        return _response.data

    def update(
        self,
        *,
        projects_groups: typing.Optional[typing.Sequence[ProjectGroupRequest]] = OMIT,
        roles_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        workspaces_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SamlSettingsUpdate:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Update SAML2 settings for the currently active organization.

        Parameters
        ----------
        projects_groups : typing.Optional[typing.Sequence[ProjectGroupRequest]]

        roles_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        workspaces_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SamlSettingsUpdate


        Examples
        --------
        from label_studio_sdk import LabelStudio, ProjectGroupRequest

        client = LabelStudio(
            api_key="YOUR_API_KEY",
        )
        client.sso.saml.update(
            projects_groups=[
                ProjectGroupRequest(
                    group="groups_test",
                    project_id=42,
                    role="Inherit",
                )
            ],
            roles_groups=[["Administrator", "groups_test"]],
            workspaces_groups=[["Default workspace", "groups_test"]],
        )
        """
        _response = self._raw_client.update(
            projects_groups=projects_groups,
            roles_groups=roles_groups,
            workspaces_groups=workspaces_groups,
            request_options=request_options,
        )
        return _response.data


class AsyncSamlClient:
    def __init__(self, *, client_wrapper: AsyncClientWrapper):
        self._raw_client = AsyncRawSamlClient(client_wrapper=client_wrapper)

    @property
    def with_raw_response(self) -> AsyncRawSamlClient:
        """
        Retrieves a raw implementation of this client that returns raw responses.

        Returns
        -------
        AsyncRawSamlClient
        """
        return self._raw_client

    async def get(self, *, request_options: typing.Optional[RequestOptions] = None) -> SamlSettings:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Retrieve SAML2 settings for the currently active organization.

        Parameters
        ----------
        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SamlSettings


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sso.saml.get()


        asyncio.run(main())
        """
        _response = await self._raw_client.get(request_options=request_options)
        return _response.data

    async def update(
        self,
        *,
        projects_groups: typing.Optional[typing.Sequence[ProjectGroupRequest]] = OMIT,
        roles_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        workspaces_groups: typing.Optional[typing.Sequence[typing.Sequence[str]]] = OMIT,
        request_options: typing.Optional[RequestOptions] = None,
    ) -> SamlSettingsUpdate:
        """
        <Card href="https://humansignal.com/goenterprise">
                <img style="pointer-events: none; margin-left: 0px; margin-right: 0px;" src="https://docs.humansignal.com/images/badge.svg" alt="Label Studio Enterprise badge"/>
                <p style="margin-top: 10px; font-size: 14px;">
                    This endpoint is not available in Label Studio Community Edition. [Learn more about Label Studio Enterprise](https://humansignal.com/goenterprise)
                </p>
            </Card>
        Update SAML2 settings for the currently active organization.

        Parameters
        ----------
        projects_groups : typing.Optional[typing.Sequence[ProjectGroupRequest]]

        roles_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        workspaces_groups : typing.Optional[typing.Sequence[typing.Sequence[str]]]

        request_options : typing.Optional[RequestOptions]
            Request-specific configuration.

        Returns
        -------
        SamlSettingsUpdate


        Examples
        --------
        import asyncio

        from label_studio_sdk import AsyncLabelStudio, ProjectGroupRequest

        client = AsyncLabelStudio(
            api_key="YOUR_API_KEY",
        )


        async def main() -> None:
            await client.sso.saml.update(
                projects_groups=[
                    ProjectGroupRequest(
                        group="groups_test",
                        project_id=42,
                        role="Inherit",
                    )
                ],
                roles_groups=[["Administrator", "groups_test"]],
                workspaces_groups=[["Default workspace", "groups_test"]],
            )


        asyncio.run(main())
        """
        _response = await self._raw_client.update(
            projects_groups=projects_groups,
            roles_groups=roles_groups,
            workspaces_groups=workspaces_groups,
            request_options=request_options,
        )
        return _response.data
